==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Trang nhà', # MODIF
	'articles' => 'Bài',
	'articles_auteur' => 'Bài vở của tác giả này',
	'articles_populaires' => 'Những bài được chuộng nhất',
	'articles_rubrique' => 'Bài vở của đề mục này',
	'aucun_article' => 'Không có bài tại địa chì này  ',
	'aucun_auteur' => 'Không có tác giả tại địa chì này',
	'aucun_site' => 'Không có trang Web tại địa chì này ',
	'aucune_breve' => 'Không có tin ngắn tại địa chì này',
	'aucune_rubrique' => 'Không có đề mục tại địa chì này',
	'autres_breves' => 'Những tin ngằn khác ',
	'autres_groupes_mots_clefs' => 'Những nhóm từ then chốt khác ',
	'autres_sites' => 'Những trang Web khác',

	// B
	'bonjour' => 'Thân chào',

	// C
	'commenter_site' => 'Phê bình trang Web này',

	// D
	'date' => 'Ngày',
	'dernier_ajout' => 'Bài được thêm sau chót',
	'dernieres_breves' => 'Những tin ngắn mới nhất ',
	'derniers_articles' => 'Những bài mới nhất ',
	'derniers_commentaires' => 'Các góp ý mới nhất',
	'derniers_messages_forum' => 'Trao đổi mới nhất hiện trong diễn đàn',

	// E
	'edition_mode_texte' => 'văn bản thường',
	'en_reponse' => 'Trả lời cho :',
	'en_resume' => 'Tóm tắt',
	'envoyer_message' => 'Gửi thư tín mới',
	'espace_prive' => 'Mạng cá nhân',

	// H
	'hierarchie_site' => 'Cấu trúc thứ bậc của trang web',

	// J
	'jours' => 'ngày',

	// M
	'meme_auteur' => 'Cùng tác giả',
	'meme_rubrique' => 'Trong cùng đề mục',
	'memes_auteurs' => 'Cùng tác giả',
	'message' => 'Thư tín',
	'messages_forum' => 'Thư tín diễn đàn', # MODIF
	'messages_recents' => 'Tin mới nhất trong diễn đàn',
	'mots_clefs' => 'Từ then chốt',
	'mots_clefs_meme_groupe' => 'Từ then chốt cùng nhòm  ',

	// N
	'navigation' => 'Điều hướng',
	'nom' => 'Tên',
	'nouveautes' => 'Những điểm mới',
	'nouveautes_web' => 'Những điều mới trên trang web',
	'nouveaux_articles' => 'Bài mới',
	'nouvelles_breves' => 'Tin ngắn mới',

	// P
	'page_precedente' => 'trang trước',
	'page_suivante' => 'trang sau',
	'par_auteur' => 'bởi',
	'participer_site' => 'Bạn có thể tham gia đóng góp tích cực vào trang web này để soạn và đăng bài vở. Bạn phải ghi danh dưới đây. Sau đó bạn sẽ nhận email cho biết chi tiết để vào trang web.',
	'plan_site' => 'Sơ đồ',
	'popularite' => 'Mức độ phổ thông',
	'poster_message' => 'Để đăng tin',
	'proposer_site' => 'Bạn có thể đề nghị thêm một trang web vào phần này:',

	// R
	'repondre_article' => 'Trả lời bài này',
	'repondre_breve' => 'Trả lời tin ngắn này',
	'resultats_recherche' => 'Kết quả tìm kiếm',
	'retour_debut_forums' => 'Trở về trang đầu của diễn đàn',
	'rubrique' => 'Ðề Mục',
	'rubriques' => 'Ðề Mục',

	// S
	'signatures_petition' => 'Chữ ký',
	'site_realise_avec_spip' => 'Trang web được soạn bằng SPIP',
	'sites_web' => 'Trang web',
	'sous_rubriques' => 'Đề mục phụ',
	'suite' => 'tiếp tục',
	'sur_web' => 'Trên trang web',
	'syndiquer_rubrique' => 'Phổ biến đề mục này',
	'syndiquer_site' => 'Phổ biến trọn trang web',

	// T
	'texte_lettre_information' => 'Đây là bản tin của trang web',
	'texte_lettre_information_2' => 'Tóm tắt các bài vở và tin ngắn đã phát hành từ ', # MODIF

	// V
	'ver_imprimer' => 'Kiểu dể in',
	'voir_en_ligne' => 'Xem online'
);

==> spip_4.4.5+dfsg.orig.tar.xz: ecrire/lang/public_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=vi
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Trang nhà', # MODIF
	'articles' => 'Bài',
	'articles_auteur' => 'Bài vở của tác giả này',
	'articles_populaires' => 'Những bài được chuộng nhất',
	'articles_rubrique' => 'Bài vở của đề mục này',
	'aucun_article' => 'Không có bài tại địa chì này  ',
	'aucun_auteur' => 'Không có tác giả tại địa chì này',
	'aucun_site' => 'Không có trang Web tại địa chì này ',
	'aucune_breve' => 'Không có tin ngắn tại địa chì này',
	'aucune_rubrique' => 'Không có đề mục tại địa chì này',
	'autres_breves' => 'Những tin ngằn khác ',
	'autres_groupes_mots_clefs' => 'Những nhóm từ then chốt khác ',
	'autres_sites' => 'Những trang Web khác',

	// B
	'bonjour' => 'Thân chào',

	// C
	'commenter_site' => 'Phê bình trang Web này',

	// D
	'date' => 'Ngày',
	'dernier_ajout' => 'Bài được thêm sau chót',
	'dernieres_breves' => 'Những tin ngắn mới nhất ',
	'derniers_articles' => 'Những bài mới nhất ',
	'derniers_commentaires' => 'Các góp ý mới nhất',
	'derniers_messages_forum' => 'Trao đổi mới nhất hiện trong diễn đàn',

	// E
	'edition_mode_texte' => 'văn bản thường',
	'en_reponse' => 'Trả lời cho :',
	'en_resume' => 'Tóm tắt',
	'envoyer_message' => 'Gửi thư tín mới',
	'espace_prive' => 'Mạng cá nhân',

	// H
	'hierarchie_site' => 'Cấu trúc thứ bậc của trang web',

	// J
	'jours' => 'ngày',

	// M
	'meme_auteur' => 'Cùng tác giả',
	'meme_rubrique' => 'Trong cùng đề mục',
	'memes_auteurs' => 'Cùng tác giả',
	'message' => 'Thư tín',
	'messages_forum' => 'Thư tín diễn đàn', # MODIF
	'messages_recents' => 'Tin mới nhất trong diễn đàn',
	'mots_clefs' => 'Từ then chốt',
	'mots_clefs_meme_groupe' => 'Từ then chốt cùng nhòm  ',

	// N
	'navigation' => 'Điều hướng',
	'nom' => 'Tên',
	'nouveautes' => 'Những điểm mới',
	'nouveautes_web' => 'Những điều mới trên trang web',
	'nouveaux_articles' => 'Bài mới',
	'nouvelles_breves' => 'Tin ngắn mới',

	// P
	'page_precedente' => 'trang trước',
	'page_suivante' => 'trang sau',
	'par_auteur' => 'bởi',
	'participer_site' => 'Bạn có thể tham gia đóng góp tích cực vào trang web này để soạn và đăng bài vở. Bạn phải ghi danh dưới đây. Sau đó bạn sẽ nhận email cho biết chi tiết để vào trang web.',
	'plan_site' => 'Sơ đồ',
	'popularite' => 'Mức độ phổ thông',
	'poster_message' => 'Để đăng tin',
	'proposer_site' => 'Bạn có thể đề nghị thêm một trang web vào phần này:',

	// R
	'repondre_article' => 'Trả lời bài này',
	'repondre_breve' => 'Trả lời tin ngắn này',
	'resultats_recherche' => 'Kết quả tìm kiếm',
	'retour_debut_forums' => 'Trở về trang đầu của diễn đàn',
	'rubrique' => 'Ðề Mục',
	'rubriques' => 'Ðề Mục',

	// S
	'signatures_petition' => 'Chữ ký',
	'site_realise_avec_spip' => 'Trang web được soạn bằng SPIP',
	'sites_web' => 'Trang web',
	'sous_rubriques' => 'Đề mục phụ',
	'suite' => 'tiếp tục',
	'sur_web' => 'Trên trang web',
	'syndiquer_rubrique' => 'Phổ biến đề mục này',
	'syndiquer_site' => 'Phổ biến trọn trang web',

	// T
	'texte_lettre_information' => 'Đây là bản tin của trang web',
	'texte_lettre_information_2' => 'Tóm tắt các bài vở và tin ngắn đã phát hành từ ', # MODIF

	// V
	'ver_imprimer' => 'Kiểu dể in',
	'voir_en_ligne' => 'Xem online',
];
